@@ -85,8 +85,6 @@ class Experiment:
             factor '7' removes weekly seasonality, and the ``+1`` accounts
             for the fact that enrollment typically starts a few hours
             before UTC midnight.
-        app_id (str, optional): For a Glean app, the name of the BigQuery
-            dataset derived from its app ID, like `org_mozilla_firefox`.
 
     Attributes:
         experiment_slug (str): Name of the study, used to identify
@@ -105,7 +103,6 @@ class Experiment:
     experiment_slug = attr.ib()
     start_date = attr.ib()
     num_dates_enrollment = attr.ib(default=None)
-    app_id = attr.ib(default=None)
 
     def get_single_window_data(
         self, bq_context, metric_list, last_date_full_data,
@@ -132,10 +129,9 @@ class Experiment:
                 collected outside this analysis window.
             analysis_length_days (int): the length of the analysis window,
                 measured in days.
-            enrollments_query_type ('normandy' or 'fenix-fallback'):
-                Specifies the query type to use to get the experiment's
-                enrollments, unless overridden by
-                ``custom_enrollments_query``.
+            enrollments_query_type (str): Specifies the query type to use to
+                get the experiment's enrollments, unless overridden by
+                custom_enrollments_query.
             custom_enrollments_query (str): A full SQL query to be used
                 in the main query::
 
@@ -176,21 +172,16 @@ class Experiment:
             analysis_length_days, self.num_dates_enrollment
         )
 
-        sql_template = self.build_query(
-            metric_list=metric_list,
-            time_limits=time_limits,
-            enrollments_query_type=enrollments_query_type,
-            custom_enrollments_query=custom_enrollments_query,
-            segment_list=segment_list,
+        sql = self.build_query(
+            metric_list, time_limits, enrollments_query_type, custom_enrollments_query,
+            segment_list
         )
 
-        full_res_table_name = sanitize_table_name_for_bq('_'.join(
-            [last_date_full_data, self.experiment_slug, hash_ish(sql_template)]
+        res_table_name = sanitize_table_name_for_bq('_'.join(
+            [last_date_full_data, self.experiment_slug, hash_ish(sql)]
         ))
 
-        sql = sql_template.format(results_table=full_res_table_name)
-
-        return bq_context.run_script_or_fetch(sql, full_res_table_name).to_dataframe()
+        return bq_context.run_query(sql, res_table_name).to_dataframe()
 
     def get_time_series_data(
         self, bq_context, metric_list, last_date_full_data,
@@ -212,10 +203,9 @@ class Experiment:
                 experiment recipe was deactivated), then do that here.
             time_series_period ('daily' or 'weekly'): How long each
                 analysis window should be.
-            enrollments_query_type ('normandy' or 'fenix-fallback'):
-                Specifies the query type to use to get the experiment's
-                enrollments, unless overridden by
-                ``custom_enrollments_query``.
+            enrollments_query_type (str): Specifies the query type to use to
+                get the experiment's enrollments, unless overridden by
+                custom_enrollments_query.
             custom_enrollments_query (str): A full SQL query to be used
                 in the main query::
 
@@ -225,8 +215,7 @@ class Experiment:
                 segments to study.
 
         Returns:
-            A :class:`mozanalysis.experiment.TimeSeriesResult` object,
-            which may be used to obtain a
+            A TimeSeriesResult object, which may be used to obtain a
             pandas DataFrame of per-client metric data, for each
             analysis window. Each DataFrame is a pandas DataFrame in
             "the standard format": one row per client, some metadata
@@ -254,21 +243,16 @@ class Experiment:
             self.num_dates_enrollment
         )
 
-        sql_template = self.build_query_template(
-            metric_list=metric_list,
-            time_limits=time_limits,
-            enrollments_query_type=enrollments_query_type,
-            custom_enrollments_query=custom_enrollments_query,
-            segment_list=segment_list,
+        sql = self.build_query(
+            metric_list, time_limits, enrollments_query_type, custom_enrollments_query,
+            segment_list
         )
 
         full_res_table_name = sanitize_table_name_for_bq('_'.join(
-            [last_date_full_data, self.experiment_slug, hash_ish(sql_template)]
+            [last_date_full_data, self.experiment_slug, hash_ish(sql)]
         ))
 
-        sql = sql_template.format(results_table=full_res_table_name)
-
-        bq_context.run_script_or_fetch(sql, full_res_table_name)
+        bq_context.run_query(sql, full_res_table_name)
 
         return TimeSeriesResult(
             fully_qualified_table_name=bq_context.fully_qualify_table_name(
@@ -277,18 +261,11 @@ class Experiment:
             analysis_windows=time_limits.analysis_windows
         )
 
-    def build_query_template(
-        self,
-        metric_list,
-        time_limits,
-        enrollments_query_type='normandy',
-        custom_enrollments_query=None,
-        segment_list=None,
+    def build_query(
+        self, metric_list, time_limits, enrollments_query_type='normandy',
+        custom_enrollments_query=None, segment_list=None
     ) -> str:
-        """Return a SQL template for querying metric data.
-
-        The return value is a Python string template that needs to be formatted
-        with a value for `results_table` before it is valid SQL.
+        """Return SQL to query metric data.
 
         For interactive use, prefer :meth:`.get_time_series_data` or
         :meth:`.get_single_window_data`, according to your use case,
@@ -300,11 +277,9 @@ class Experiment:
                 The metrics to analyze.
             time_limits (TimeLimits): An object describing the
                 interval(s) to query
-            results_table (str): The name of the table to write
-            enrollments_query_type ('normandy' or 'fenix-fallback'):
-                Specifies the query type to use to get the experiment's
-                enrollments, unless overridden by
-                ``custom_enrollments_query``.
+            enrollments_query_type (str): Specifies the query type to use to
+                get the experiment's enrollments, unless overridden by
+                custom_enrollments_query.
             custom_enrollments_query (str): A full SQL query to be used
                 in the main query::
 
@@ -334,33 +309,29 @@ class Experiment:
         )
 
         return """
-    CREATE TEMPORARY TABLE enrollments AS (
-        WITH analysis_windows AS (
-            {analysis_windows_query}
-        ),
-        raw_enrollments AS ({enrollments_query}),
-        segmented_enrollments AS ({segments_query})
-
+    WITH analysis_windows AS (
+        {analysis_windows_query}
+    ),
+    raw_enrollments AS ({enrollments_query}),
+    segmented_enrollments AS ({segments_query}),
+    enrollments AS (
         SELECT
             e.*,
             aw.*
         FROM segmented_enrollments e
         CROSS JOIN analysis_windows aw
-    );
-
-    CREATE OR REPLACE TABLE {{results_table}} AS (
-        SELECT
-            enrollments.*,
-            {metrics_columns}
-        FROM enrollments
-        {metrics_joins}
-    );
+    )
+    SELECT
+        enrollments.*,
+        {metrics_columns}
+    FROM enrollments
+    {metrics_joins}
         """.format(
             analysis_windows_query=analysis_windows_query,
             enrollments_query=enrollments_query,
             segments_query=segments_query,
             metrics_columns=',\n        '.join(metrics_columns),
-            metrics_joins='\n'.join(metrics_joins),
+            metrics_joins='\n'.join(metrics_joins)
         )
 
     @staticmethod
@@ -386,8 +357,8 @@ class Experiment:
         """Return SQL to query a list of enrollments and their branches"""
         if enrollments_query_type == 'normandy':
             return self._build_enrollments_query_normandy(time_limits)
-        elif enrollments_query_type == 'fenix-fallback':
-            return self._build_enrollments_query_fenix_baseline(time_limits)
+        elif enrollments_query_type == 'glean':
+            raise NotImplementedError
         else:
             raise ValueError
 
@@ -396,7 +367,7 @@ class Experiment:
         return """
         SELECT
             e.client_id,
-            `mozfun.map.get_key`(e.event_map_values, 'branch')
+            `moz-fx-data-shared-prod.udf.get_key`(e.event_map_values, 'branch')
                 AS branch,
             min(e.submission_date) AS enrollment_date,
             count(e.submission_date) AS num_enrollment_events
@@ -415,44 +386,6 @@ class Experiment:
             last_enrollment_date=time_limits.last_enrollment_date,
         )
 
-    def _build_enrollments_query_fenix_baseline(self, time_limits):
-        """Return SQL to query enrollments for a Fenix no-event experiment
-
-        If enrollment events are available for this experiment, then you
-        can take a better approach than this method. But in the absence
-        of enrollment events (e.g. in a Mako-based experiment, which
-        does not send enrollment events), you need to fall back to using
-        ``ping_info.experiments`` to get a list of who is in what branch
-        and when they enrolled.
-        """
-        # Try to ignore users who enrolled early - but only consider a
-        # 7 day window
-        return """
-        SELECT
-            b.client_info.client_id AS client_id,
-            mozfun.map.get_key(
-                b.ping_info.experiments,
-                '{experiment_slug}'
-            ).branch,
-            DATE(MIN(b.submission_timestamp)) AS enrollment_date
-        FROM `moz-fx-data-shared-prod.{dataset}.baseline` b
-        WHERE
-            DATE(b.submission_timestamp)
-                BETWEEN DATE_SUB('{first_enrollment_date}', INTERVAL 7 DAY)
-                AND '{last_enrollment_date}'
-            AND mozfun.map.get_key(
-                b.ping_info.experiments,
-                '{experiment_slug}'
-            ).branch IS NOT NULL
-        GROUP BY client_id, branch
-        HAVING enrollment_date >= '{first_enrollment_date}'
-            """.format(
-            experiment_slug=self.experiment_slug,
-            first_enrollment_date=time_limits.first_enrollment_date,
-            last_enrollment_date=time_limits.last_enrollment_date,
-            dataset=self.app_id or "org_mozilla_firefox",
-        )
-
     def _build_metrics_query_bits(self, metric_list, time_limits):
         """Return lists of SQL fragments corresponding to metrics."""
         ds_metrics = self._partition_by_data_source(metric_list)
@@ -466,7 +399,7 @@ class Experiment:
 
         for i, ds in enumerate(ds_metrics.keys()):
             query_for_metrics = ds.build_query(
-                ds_metrics[ds], time_limits, self.experiment_slug, self.app_id
+                ds_metrics[ds], time_limits, self.experiment_slug
             )
             metrics_joins.append(
                 """    LEFT JOIN (
@@ -531,7 +464,7 @@ class Experiment:
 
         for i, ds in enumerate(ds_segments.keys()):
             query_for_segments = ds.build_query(
-                ds_segments[ds], time_limits, self.experiment_slug, self.app_id
+                ds_segments[ds], time_limits, self.experiment_slug
             )
             segments_joins.append(
                 """    LEFT JOIN (
@@ -690,9 +623,6 @@ class TimeLimits:
                 time_series_period
             ))
 
-        if num_dates_enrollment <= 0:
-            raise ValueError("Number of enrollment dates must be a positive number")
-
         analysis_window_length_dates = 1 if time_series_period == 'daily' else 7
 
         last_enrollment_date = add_days(
